REGIONS = {u'ad': u'\u0d06\u0d28\u0d4d\u200d\u0d21\u0d4b\u0d31\u0d3e',
 u'ae': u'\u0d2f\u0d41.\u0d0e.\u0d07',
 u'af': u'\u0d05\u0d2b\u0d4d\u0d17\u0d3e\u0d28\u0d3f\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d4d\u200d',
 u'ag': u'\u0d06\u0d28\u0d4d\u200d\u0d31\u0d4d\u0d31\u0d3f\u0d17\u0d4d\u0d35\u0d3e \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d2c\u0d30\u0d4d\u200d\u0d2c\u0d42\u0d21\u0d3e',
 u'ai': u'\u0d06\u0d28\u0d4d\u200d\u0d17\u0d4d\u0d35\u0d3f\u0d32\u0d3e',
 u'al': u'\u0d05\u0d32\u0d4d\u200d\u0d2c\u0d3e\u0d28\u0d3f\u0d2f\u0d3e',
 u'am': u'\u0d05\u0d30\u0d4d\u200d\u0d2e\u0d47\u0d28\u0d3f\u0d2f\u0d3e',
 u'an': u'\u0d28\u0d46\u0d25\u0d30\u0d4d\u200d\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d\u0d38\u0d4d \u0d06\u0d28\u0d4d\u0d31\u0d3f\u0d32\u0d4d\u200d\u0d38\u0d4d',
 u'ao': u'\u0d06\u0d28\u0d4d\u200d\u0d17\u0d4b\u0d33\u0d3e',
 u'aq': u'\u0d05\u0d28\u0d4d\u0d31\u0d3e\u0d30\u0d4d\u200d\u0d1f\u0d4d\u0d1f\u0d3f\u0d15\u0d4d\u0d15',
 u'ar': u'\u0d05\u0d30\u0d4d\u200d\u0d1c\u0d46\u0d28\u0d4d\u0d31\u0d40\u0d28',
 u'as': u'\u0d05\u0d2e\u0d47\u0d30\u0d3f\u0d15\u0d4d\u0d15\u0d28\u0d4d\u200d \u0d38\u0d2e\u0d4b\u0d35\u0d3e',
 u'at': u'\u0d13\u0d38\u0d4d\u0d1f\u0d4d\u0d30\u0d3f\u0d2f',
 u'au': u'\u0d13\u0d38\u0d4d\u0d1f\u0d4d\u0d30\u0d47\u0d32\u0d3f\u0d2f\u0d3e',
 u'aw': u'\u0d05\u0d30\u0d41\u0d2c\u0d3e',
 u'ax': u'\xc5land \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'az': u'\u0d05\u0d38\u0d30\u0d4d\u200d\u0d2c\u0d48\u0d1c\u0d28\u0d4d\u200d',
 u'ba': u'\u0d2c\u0d4b\u0d38\u0d4d\u0d28\u0d3f\u0d2f\u0d3e \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d39\u0d46\u0d30\u0d4d\u200d\u0d38\u0d46\u0d17\u0d4b\u0d35\u0d3e\u0d28\u0d3f\u0d2f\u0d3e',
 u'bb': u'\u0d2c\u0d30\u0d4d\u200d\u0d2c\u0d3e\u0d21\u0d4b\u0d38\u0d4d',
 u'bd': u'\u0d2c\u0d02\u0d17\u0d4d\u0d32\u0d3e\u0d26\u0d47\u0d36\u0d4d',
 u'be': u'\u0d2c\u0d46\u0d32\u0d4d\u200d\u0d1c\u0d3f\u0d2f\u0d02',
 u'bf': u'\u0d2c\u0d30\u0d4d\u200d\u0d15\u0d4d\u0d15\u0d3f\u0d28\u0d3e \u0d2b\u0d3e\u0d38\u0d4b',
 u'bg': u'\u0d2c\u0d33\u0d4d\u200d\u0d17\u0d47\u0d31\u0d3f\u0d2f\u0d3e',
 u'bh': u'\u0d2c\u0d39\u0d4d\u200c\u0d31\u0d48\u0d28\u0d4d\u200d',
 u'bi': u'\u0d2c\u0d41\u0d31\u0d41\u0d23\u0d4d\u0d1f\u0d3f',
 u'bj': u'\u0d2c\u0d46\u0d28\u0d3f\u0d28\u0d4d\u200d',
 u'bl': u'\u0d38\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u0d31\u0d4d \u0d2c\u0d30\u0d4d\u200d\u0d25\u0d4d\u0d32\u0d46\u0d2e\u0d3f',
 u'bm': u'\u0d2c\u0d30\u0d4d\u200d\u0d2e\u0d42\u0d21\u0d3e',
 u'bn': u'\u0d2c\u0d4d\u0d30\u0d41\u0d23\u0d47\u0d2f\u0d4d\u200c \u0d26\u0d3e\u0d30\u0d41\u0d38\u0d4d\u0d38\u0d32\u0d3e\u0d02',
 u'bo': u'\u0d2c\u0d4a\u0d33\u0d3f\u0d35\u0d3f\u0d2f',
 u'br': u'\u0d2c\u0d4d\u0d30\u0d38\u0d40\u0d32\u0d4d\u200d',
 u'bs': u'\u0d2c\u0d39\u0d3e\u0d2e\u0d3e\u0d38\u0d4d',
 u'bt': u'\u0d2c\u0d42\u0d1f\u0d4d\u0d1f\u0d3e\u0d28\u0d4d\u200d',
 u'bv': u'\u0d2c\u0d4c\u0d35\u0d46\u0d31\u0d4d\u0d31\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d4d',
 u'bw': u'\u0d2c\u0d4b\u0d1f\u0d4d\u0d1f\u0d4d\u0d38\u0d4d\u0d35\u0d3e\u0d28\u0d3e',
 u'by': u'\u0d2c\u0d46\u0d32\u0d3e\u0d31\u0d38\u0d4d',
 u'bz': u'\u0d2c\u0d46\u0d32\u0d3f\u0d38\u0d4d\u0d38\u0d46',
 u'ca': u'\u0d15\u0d3e\u0d28\u0d21\u0d3e',
 u'cc': u'\u0d15\u0d4a\u0d15\u0d4d\u0d15\u0d4b\u0d38\u0d4d (\u0d15\u0d40\u0d32\u0d3f\u0d19\u0d4d) \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'cd': u'\u0d15\u0d4b\u0d19\u0d4d\u0d15\u0d4b-\u0d15\u0d3f\u0d28\u0d4d\u200d\u0d39\u0d3e\u0d38\u0d3e',
 u'cf': u'\u0d38\u0d46\u0d28\u0d4d\u200d\u0d1f\u0d4d\u0d30\u0d32\u0d4d\u200d \u0d06\u0d2b\u0d4d\u0d30\u0d3f\u0d15\u0d4d\u0d15\u0d28\u0d4d\u200d \u0d31\u0d3f\u0d2a\u0d2c\u0d4d\u0d32\u0d3f\u0d15\u0d4d\u0d15\u0d4d',
 u'cg': u'\u0d15\u0d4b\u0d19\u0d4d\u0d15\u0d4b-\u0d2c\u0d4d\u0d30\u0d3e\u0d38\u0d3e\u0d35\u0d3f\u0d32\u0d3f',
 u'ch': u'\u0d38\u0d4d\u0d35\u0d3f\u0d31\u0d4d\u0d31\u0d4d\u0d38\u0d30\u0d4d\u200d\u0d32\u0d28\u0d4d\u200d\u0d21\u0d4d\u200c',
 u'ci': u'\u0d10\u0d35\u0d31\u0d3f \u0d15\u0d4b\u0d38\u0d4d\u0d31\u0d4d\u0d31\u0d4d',
 u'ck': u'\u0d15\u0d41\u0d15\u0d4d\u0d15\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'cl': u'\u0d1a\u0d3f\u0d32\u0d3f',
 u'cm': u'\u0d15\u0d3e\u0d2e\u0d3e\u0d31\u0d42\u0d23\u0d4d\u200d',
 u'cn': u'\u0d1a\u0d48\u0d28',
 u'co': u'\u0d15\u0d02\u0d2c\u0d4a\u0d21\u0d3f\u0d2f',
 u'cr': u'\u0d15\u0d4b\u0d38\u0d4d\u0d31\u0d4d\u0d31\u0d3e \u0d31\u0d3f\u0d15\u0d4d\u0d15\u0d3e',
 u'cu': u'\u0d15\u0d4d\u0d2f\u0d42\u0d2c\u0d3e',
 u'cv': u'\u0d15\u0d46\u0d2f\u0d3f\u0d2a\u0d4d \u0d35\u0d46\u0d30\u0d4d\u200d\u0d21\u0d46',
 u'cx': u'\u0d15\u0d4d\u0d30\u0d3f\u0d38\u0d4d\u0d24\u0d4d\u0d2e\u0d38\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d4d',
 u'cy': u'\u0d38\u0d48\u0d2a\u0d4d\u0d30\u0d38\u0d4d',
 u'cz': u'\u0d1a\u0d46\u0d15\u0d4d\u0d15\u0d4d \u0d31\u0d3f\u0d2a\u0d2c\u0d4d\u0d32\u0d3f\u0d15\u0d4d\u0d15\u0d4d',
 u'de': u'\u0d1c\u0d30\u0d4d\u200d\u0d2e\u0d28\u0d3f',
 u'dj': u'\u0d1c\u0d3f\u0d2c\u0d47\u0d3e\u0d1f\u0d4d\u0d1f\u0d3f',
 u'dk': u'\u0d21\u0d46\u0d28\u0d4d\u200d\u0d2e\u0d3e\u0d30\u0d4d\u200d\u0d15\u0d4d\u0d15\u0d4d',
 u'dm': u'\u0d21\u0d4a\u0d2e\u0d3f\u0d28\u0d3f\u0d15\u0d4d\u0d15\u0d3e',
 u'do': u'\u0d21\u0d4a\u0d2e\u0d46\u0d28\u0d3f\u0d15\u0d4d\u0d15\u0d28\u0d4d\u200d \u0d31\u0d3f\u0d2a\u0d4d\u0d2a\u0d2c\u0d4d\u0d32\u0d3f\u0d15\u0d4d\u0d15\u0d4d\u200c',
 u'dz': u'\u0d05\u0d33\u0d4d\u200d\u0d1c\u0d40\u0d30\u0d3f\u0d2f',
 u'ec': u'\u0d07\u0d15\u0d4d\u0d15\u0d4d\u0d35\u0d21\u0d4b\u0d30\u0d4d\u200d',
 u'ee': u'\u0d0e\u0d38\u0d4d\u0d31\u0d4d\u0d31\u0d4b\u0d23\u0d3f\u0d2f\u0d3e',
 u'eg': u'\u0d08\u0d1c\u0d3f\u0d2a\u0d4d\u0d31\u0d4d\u0d31\u0d4d',
 u'eh': u'\u0d2a\u0d1f\u0d3f\u0d1e\u0d4d\u0d1e\u0d3e\u0d31\u0d28\u0d4d\u200d \u0d38\u0d39\u0d3e\u0d31\u0d3e',
 u'er': u'\u0d0e\u0d31\u0d3f\u0d1f\u0d4d\u0d30\u0d3f\u0d2f\u0d3e',
 u'es': u'\u0d38\u0d4d\u0d2a\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u200d',
 u'et': u'\u0d0e\u0d2b\u0d3f\u0d2f\u0d4b\u0d2a\u0d4d\u0d2a\u0d3f\u0d2f\u0d3e',
 u'fi': u'\u0d2b\u0d3f\u0d28\u0d4d\u200d\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d\u200c',
 u'fj': u'\u0d2b\u0d3f\u0d1c\u0d3f',
 u'fk': u'\u0d2b\u0d4b\u0d15\u0d4d\u0d15\u0d4d\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d (\u0d2e\u0d3e\u0d32\u0d4d\u200d\u0d35\u0d3f\u0d28\u0d3e\u0d38\u0d4d)',
 u'fm': u'\u0d2e\u0d48\u0d15\u0d4d\u0d30\u0d4b\u0d23\u0d47\u0d37\u0d4d\u0d2f\u0d3e',
 u'fo': u'\u0d2b\u0d3e\u0d31\u0d4b \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'fr': u'\u0d2b\u0d4d\u0d30\u0d3e\u0d28\u0d4d\u200d\u0d38\u0d4d\u200c',
 u'ga': u'\u0d17\u0d3e\u0d2c\u0d23\u0d4d\u200d',
 u'gb': u'\u0d2f\u0d41\u0d23\u0d48\u0d31\u0d4d\u0d31\u0d21\u0d4d\u200c \u0d15\u0d3f\u0d02\u0d19\u0d4d\u0d21\u0d02',
 u'gd': u'\u0d17\u0d4d\u0d30\u0d28\u0d47\u0d21\u0d3e',
 u'ge': u'\u0d1c\u0d4b\u0d30\u0d4d\u200d\u0d1c\u0d3f\u0d2f\u0d3e',
 u'gf': u'\u0d2b\u0d4d\u0d30\u0d46\u0d1e\u0d4d\u0d1a\u0d4d \u0d17\u0d41\u0d2f\u0d3f\u0d28\u0d3e',
 u'gg': u'\u0d17\u0d4d\u0d35\u0d47\u0d30\u0d4d\u200d\u0d23\u0d4d\u200d\u0d38\u0d3f',
 u'gh': u'\u0d17\u0d3e\u0d28\u0d3e',
 u'gi': u'\u0d17\u0d3f\u0d2c\u0d4d\u0d30\u0d3e\u0d32\u0d4d\u200d\u0d1f\u0d4d\u0d1f\u0d30\u0d4d\u200d',
 u'gl': u'\u0d17\u0d4d\u0d30\u0d40\u0d28\u0d4d\u200d\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d',
 u'gm': u'\u0d17\u0d3e\u0d02\u0d2c\u0d3f\u0d2f\u0d3e',
 u'gn': u'\u0d17\u0d28\u0d3f\u0d2f\u0d3e',
 u'gp': u'\u0d17\u0d4d\u0d35\u0d3e\u0d21\u0d3f\u0d32\u0d4b\u0d2a\u0d4d',
 u'gq': u'\u0d07\u0d15\u0d4d\u0d35\u0d3e\u0d1f\u0d4b\u0d31\u0d3f\u0d2f\u0d32\u0d4d\u200d \u0d17\u0d28\u0d3f\u0d2f\u0d3e',
 u'gr': u'\u0d17\u0d4d\u0d30\u0d40\u0d38\u0d4d',
 u'gs': u'\u0d35\u0d1f\u0d15\u0d4d\u0d15\u0d28\u0d4d\u200d \u0d1c\u0d4b\u0d30\u0d4d\u200d\u0d1c\u0d3f\u0d2f\u0d2f\u0d41\u0d02 \u0d35\u0d1f\u0d15\u0d4d\u0d15\u0d28\u0d4d\u200d \u0d38\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d\u200c\u0d35\u0d3f\u0d1a\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d41\u0d02',
 u'gt': u'\u0d17\u0d4d\u0d35\u0d3e\u0d1f\u0d4d\u0d1f\u0d3f\u0d2e\u0d3e\u0d32\u0d3e',
 u'gu': u'\u0d17\u0d4d\u0d35\u0d3e\u0d02',
 u'gw': u'\u0d17\u0d28\u0d3f\u0d2f\u0d3e-\u0d2c\u0d3f\u0d38\u0d3e\u0d35\u0d41',
 u'gy': u'\u0d17\u0d2f\u0d3e\u0d28\u0d3e',
 u'hk': u'\u0d39\u0d4b\u0d19\u0d4d \u0d15\u0d4b\u0d19\u0d4d',
 u'hm': u'\u0d39\u0d47\u0d30\u0d4d\u200d\u0d21\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d02 \u0d2e\u0d15\u0d4d \u0d21\u0d4a\u0d28\u0d3e\u0d33\u0d4d\u200d\u0d21\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d41\u0d02',
 u'hn': u'\u0d39\u0d4a\u0d23\u0d4d\u200d\u0d21\u0d41\u0d31\u0d3e\u0d38\u0d4d\u200c',
 u'hr': u'\u0d15\u0d4d\u0d30\u0d4a\u0d2f\u0d47\u0d37\u0d4d\u0d2f\u0d3e',
 u'ht': u'\u0d39\u0d2f\u0d3f\u0d24\u0d4d\u0d24\u0d3f',
 u'hu': u'\u0d39\u0d02\u0d17\u0d31\u0d3f',
 u'id': u'\u0d07\u0d28\u0d4d\u200d\u0d21\u0d4b\u0d28\u0d47\u0d37\u0d4d\u0d2f\u0d3e',
 u'ie': u'\u0d05\u0d2f\u0d30\u0d4d\u200d\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d\u200c',
 u'il': u'\u0d07\u0d38\u0d4d\u0d30\u0d3e\u0d2f\u0d47\u0d32\u0d4d\u200d',
 u'im': u'\u0d10\u0d32\u0d4d\u200d \u0d13\u0d2b\u0d4d \u0d2e\u0d3e\u0d28\u0d4d\u200d',
 u'in': u'\u0d07\u0d28\u0d4d\u0d24\u0d4d\u0d2f',
 u'io': u'\u0d2c\u0d4d\u0d30\u0d3f\u0d1f\u0d4d\u0d1f\u0d40\u0d37\u0d4d \u0d07\u0d28\u0d4d\u0d24\u0d4d\u0d2f\u0d28\u0d4d\u200d \u0d13\u0d37\u0d4d\u0d2f\u0d28\u0d4d\u200d \u0d1f\u0d46\u0d31\u0d3f\u0d1f\u0d4d\u0d1f\u0d31\u0d3f',
 u'iq': u'\u0d07\u0d31\u0d3e\u0d16\u0d4d\u200c',
 u'ir': u'\u0d07\u0d31\u0d3e\u0d28\u0d4d\u200d',
 u'is': u'\u0d10\u0d38\u0d4d\u200c\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d',
 u'it': u'\u0d07\u0d31\u0d4d\u0d31\u0d32\u0d3f',
 u'je': u'\u0d1c\u0d47\u0d30\u0d4d\u200d\u0d38\u0d3f',
 u'jm': u'\u0d1c\u0d2e\u0d48\u0d15\u0d4d\u0d15',
 u'jo': u'\u0d1c\u0d4b\u0d30\u0d4d\u200d\u0d26\u0d4d\u0d26\u0d3e\u0d28\u0d4d\u200d',
 u'jp': u'\u0d1c\u0d2a\u0d4d\u0d2a\u0d3e\u0d28\u0d4d\u200d',
 u'ke': u'\u0d15\u0d46\u0d28\u0d3f\u0d2f\u0d3e',
 u'kg': u'\u0d15\u0d3f\u0d30\u0d4d\u200d\u0d17\u0d3f\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d4d\u200d',
 u'kh': u'\u0d15\u0d2e\u0d4d\u0d2a\u0d4b\u0d21\u0d3f\u0d2f\u0d3e',
 u'ki': u'\u0d15\u0d3f\u0d31\u0d3f\u0d2c\u0d24\u0d4d\u0d24\u0d3f',
 u'km': u'\u0d15\u0d4b\u0d2e\u0d31\u0d4b\u0d38\u0d4d',
 u'kn': u'\u0d38\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u0d31\u0d4d \u0d15\u0d3f\u0d31\u0d4d\u0d31\u0d3f\u0d38\u0d4d \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d28\u0d46\u0d35\u0d3f\u0d38\u0d4d',
 u'kp': u'\u0d28\u0d4b\u0d30\u0d4d\u200d\u0d24\u0d4d\u0d24\u0d4d\u200c \u0d15\u0d4a\u0d31\u0d3f\u0d2f',
 u'kr': u'\u0d38\u0d4c\u0d24\u0d4d\u0d24\u0d4d\u200c \u0d15\u0d4a\u0d31\u0d3f\u0d2f',
 u'kw': u'\u0d15\u0d41\u0d35\u0d48\u0d24\u0d4d\u0d24\u0d4d\u200c',
 u'ky': u'\u0d15\u0d46\u0d2f\u0d4d\u0d2e\u0d3e\u0d28\u0d4d\u200d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'kz': u'\u0d15\u0d38\u0d16\u0d4d\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d4d\u200d',
 u'la': u'\u0d32\u0d3e\u0d35\u0d4b\u0d38\u0d4d',
 u'lb': u'\u0d32\u0d46\u0d2c\u0d28\u0d4b\u0d28\u0d4d\u200d',
 u'lc': u'\u0d38\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u0d31\u0d4d \u0d32\u0d42\u0d38\u0d3f\u0d2f\u0d3e',
 u'li': u'\u0d32\u0d3f\u0d1a\u0d4d\u0d1a\u0d46\u0d28\u0d4d\u200d\u0d38\u0d4d\u0d31\u0d4d\u0d31\u0d40\u0d28\u0d4d\u200d',
 u'lk': u'\u0d36\u0d4d\u0d30\u0d3f \u0d32\u0d19\u0d4d\u0d15\u0d3e',
 u'lr': u'\u0d32\u0d48\u0d2c\u0d47\u0d30\u0d3f\u0d2f\u0d3e',
 u'ls': u'\u0d32\u0d46\u0d38\u0d4b\u0d25\u0d4b',
 u'lt': u'\u0d32\u0d3f\u0d25\u0d41\u0d35\u0d3e\u0d28\u0d3f\u0d2f\u0d3e',
 u'lu': u'\u0d32\u0d15\u0d4d\u0d38\u0d02\u0d2c\u0d30\u0d4d\u200d\u0d17\u0d4d\u0d17\u0d4d\u200c',
 u'lv': u'\u0d32\u0d3e\u0d1f\u0d4d\u200c\u0d35\u0d3f\u0d2f\u0d3e',
 u'ly': u'\u0d32\u0d3f\u0d2c\u0d3f\u0d2f',
 u'ma': u'\u0d2e\u0d4a\u0d31\u0d4b\u0d15\u0d4d\u0d15\u0d4b',
 u'mc': u'\u0d2e\u0d4a\u0d23\u0d3e\u0d15\u0d4d\u0d15\u0d4b',
 u'md': u'\u0d2e\u0d4a\u0d33\u0d4d\u200d\u0d21\u0d4b\u0d35, \u0d31\u0d3f\u0d2a\u0d4d\u0d2a\u0d2c\u0d4d\u0d32\u0d3f\u0d15\u0d4d\u0d15\u0d4d\u200c \u0d13\u0d2b\u0d4d\u200c',
 u'me': u'\u0d2e\u0d4b\u0d23\u0d4d\u0d1f\u0d46\u0d28\u0d40\u0d17\u0d4d\u0d30\u0d4b',
 u'mf': u'\u0d38\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u0d31\u0d4d \u0d2e\u0d3e\u0d30\u0d4d\u200d\u0d1f\u0d4d\u0d1f\u0d3f\u0d28\u0d4d\u200d',
 u'mg': u'\u0d2e\u0d3e\u0d21\u0d3e\u0d17\u0d38\u0d4d\u0d15\u0d3e\u0d30\u0d4d\u200d',
 u'mh': u'\u0d2e\u0d3e\u0d30\u0d4d\u200d\u0d37\u0d32\u0d4d\u200d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'mk': u'\u0d2e\u0d3e\u0d38\u0d3f\u0d21\u0d4b\u0d23\u0d3f\u0d2f, F.Y.R \u0d13\u0d2b\u0d4d\u200c',
 u'ml': u'\u0d2e\u0d3e\u0d32\u0d3f',
 u'mm': u'\u0d2e\u0d3f\u0d2f\u0d3e\u0d28\u0d4d\u200d\u0d2e\u0d3e\u0d30\u0d4d\u200d',
 u'mn': u'\u0d2e\u0d02\u0d17\u0d4b\u0d33\u0d3f\u0d2f\u0d3e',
 u'mo': u'\u0d2e\u0d15\u0d4d\u0d15\u0d3e\u0d35\u0d4b',
 u'mp': u'\u0d24\u0d46\u0d15\u0d4d\u0d15\u0d28\u0d4d\u200d \u0d2e\u0d31\u0d3f\u0d2f\u0d3e\u0d28\u0d3e \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'mq': u'\u0d2e\u0d3e\u0d30\u0d4d\u200d\u0d1f\u0d4d\u0d1f\u0d3f\u0d28\u0d3f\u0d15\u0d4d',
 u'mr': u'\u0d2e\u0d4c\u0d31\u0d3f\u0d1f\u0d4d\u0d1f\u0d3e\u0d28\u0d3f\u0d2f\u0d3e',
 u'ms': u'\u0d2e\u0d4b\u0d23\u0d4d\u200d\u0d38\u0d46\u0d30\u0d3e\u0d1f\u0d4d\u0d1f\u0d4d',
 u'mt': u'\u0d2e\u0d3e\u0d33\u0d4d\u200d\u0d1f\u0d4d\u0d1f\u0d3e',
 u'mu': u'\u0d2e\u0d4c\u0d30\u0d40\u0d37\u0d4d\u0d2f\u0d38\u0d4d',
 u'mv': u'\u0d2e\u0d3e\u0d32\u0d3f\u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d4d',
 u'mw': u'\u0d2e\u0d32\u0d3e\u0d35\u0d3f',
 u'mx': u'\u0d2e\u0d46\u0d15\u0d4d\u0d38\u0d3f\u0d15\u0d4d\u0d15\u0d4b',
 u'my': u'\u0d2e\u0d32\u0d47\u0d37\u0d4d\u0d2f',
 u'mz': u'\u0d2e\u0d4a\u0d38\u0d3e\u0d02\u0d2c\u0d3f\u0d15\u0d4d\u0d15\u0d4d',
 u'na': u'\u0d28\u0d2e\u0d40\u0d2c\u0d3f\u0d2f\u0d3e',
 u'nc': u'\u0d28\u0d4d\u0d2f\u0d42 \u0d38\u0d3e\u0d32\u0d3f\u0d21\u0d4b\u0d23\u0d3f\u0d2f\u0d3e',
 u'ne': u'\u0d28\u0d48\u0d1c\u0d30\u0d4d\u200d',
 u'nf': u'\u0d28\u0d4b\u0d30\u0d4d\u200d\u0d2b\u0d4b\u0d15\u0d4d\u0d15\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d4d',
 u'ng': u'\u0d28\u0d48\u0d1c\u0d40\u0d30\u0d3f\u0d2f\u0d3e',
 u'ni': u'\u0d28\u0d3f\u0d15\u0d4d\u0d15\u0d30\u0d3e\u0d17\u0d4d\u0d35\u0d3e',
 u'nl': u'\u0d28\u0d46\u0d25\u0d30\u0d4d\u200d\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d\u0d38\u0d4d',
 u'no': u'\u0d28\u0d4b\u0d30\u0d4d\u200d\u200c\u0d35\u0d47',
 u'np': u'\u0d28\u0d47\u0d2a\u0d4d\u0d2a\u0d3e\u0d33\u0d4d\u200d',
 u'nr': u'\u0d28\u0d4c\u0d31\u0d41',
 u'nu': u'\u0d28\u0d4d\u0d2f\u0d42',
 u'nz': u'\u0d28\u0d4d\u0d2f\u0d42\u0d38\u0d3f\u0d32\u0d28\u0d4d\u200d\u0d21\u0d4d\u200c',
 u'om': u'\u0d12\u0d2e\u0d3e\u0d28\u0d4d\u200d',
 u'pa': u'\u0d2a\u0d28\u0d3e\u0d2e\u0d3e',
 u'pe': u'\u0d2a\u0d46\u0d30\u0d41',
 u'pf': u'\u0d2b\u0d4d\u0d30\u0d46\u0d1e\u0d4d\u0d1a\u0d4d \u0d2a\u0d4b\u0d33\u0d3f\u0d28\u0d47\u0d37\u0d4d\u0d2f\u0d3e',
 u'pg': u'\u0d2a\u0d3e\u0d2a\u0d4d\u0d35\u0d3e \u0d28\u0d4d\u0d2f\u0d42 \u0d17\u0d28\u0d3f\u0d2f\u0d3e',
 u'ph': u'\u0d2b\u0d3f\u0d32\u0d3f\u0d2a\u0d4d\u0d2a\u0d40\u0d28\u0d4d\u200d\u0d38\u0d4d\u200c',
 u'pk': u'\u0d2a\u0d3e\u0d15\u0d4d\u0d15\u0d3f\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d4d\u200d',
 u'pl': u'\u0d2a\u0d4b\u0d33\u0d23\u0d4d\u0d1f\u0d4d\u200c',
 u'pm': u'\u0d38\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u0d31\u0d4d \u0d2a\u0d3f\u0d2f\u0d30\u0d4d\u200d \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d2e\u0d3f\u0d15\u0d4d\u0d35\u0d32\u0d23\u0d4d\u200d',
 u'pn': u'\u0d2a\u0d3f\u0d31\u0d4d\u0d31\u0d4d\u0d15\u0d2f\u0d3f\u0d28\u0d4d\u200d',
 u'pr': u'\u0d2a\u0d4b\u0d30\u0d4d\u200d\u0d1f\u0d4d\u0d1f\u0d4b\u0d31\u0d3f\u0d15\u0d4d\u0d15\u0d4b',
 u'ps': u'\u0d24\u0d3e\u0d2e\u0d38\u0d2e\u0d41\u0d33\u0d4d\u0d33 \u0d2a\u0d3e\u0d32\u0d38\u0d4d\u0d25\u0d40\u0d28\u0d3f\u0d2f\u0d28\u0d4d\u200d \u0d1f\u0d46\u0d31\u0d3f\u0d1f\u0d4d\u0d1f\u0d31\u0d3f',
 u'pt': u'\u0d2a\u0d4b\u0d30\u0d4d\u200d\u0d1a\u0d4d\u0d1a\u0d41\u0d17\u0d32\u0d4d\u200d',
 u'pw': u'\u0d2a\u0d32\u0d3e\u0d35\u0d41',
 u'py': u'\u0d2a\u0d30\u0d3e\u0d17\u0d4d\u0d35\u0d47',
 u'qa': u'\u0d16\u0d24\u0d4d\u0d24\u0d30\u0d4d\u200d',
 u're': u'\u0d31\u0d40\u0d2f\u0d42\u0d23\u0d3f\u0d2f\u0d28\u0d4d\u200d',
 u'ro': u'\u0d31\u0d4a\u0d2e\u0d3e\u0d28\u0d3f\u0d2f\u0d3e',
 u'rs': u'\u0d38\u0d46\u0d30\u0d4d\u200d\u0d2c\u0d3f\u0d2f\u0d3e',
 u'ru': u'\u0d31\u0d37\u0d4d\u0d2f\u0d28\u0d4d\u200d \u0d2b\u0d46\u0d21\u0d31\u0d47\u0d37\u0d28\u0d4d\u200d',
 u'rw': u'\u0d31\u0d41\u0d35\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d3e',
 u'sa': u'\u0d38\u0d4c\u0d26\u0d3f \u0d05\u0d31\u0d47\u0d2c\u0d4d\u0d2f',
 u'sb': u'\u0d38\u0d4b\u0d33\u0d2e\u0d23\u0d4d\u200d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'sc': u'\u0d38\u0d46\u0d2f\u0d3f\u0d37\u0d32\u0d4d\u200d\u0d38\u0d4d',
 u'sd': u'\u0d38\u0d41\u0d21\u0d3e\u0d28\u0d4d\u200d',
 u'se': u'\u0d38\u0d4d\u0d35\u0d40\u0d21\u0d28\u0d4d\u200d',
 u'sg': u'\u0d38\u0d3f\u0d02\u0d17\u0d2a\u0d4d\u0d2a\u0d42\u0d30\u0d4d\u200d',
 u'sh': u'\u0d38\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u0d31\u0d4d \u0d39\u0d46\u0d32\u0d47\u0d28\u0d3e',
 u'si': u'\u0d38\u0d4d\u0d32\u0d4b\u0d35\u0d47\u0d28\u0d3f\u0d2f\u0d3e',
 u'sj': u'\u0d38\u0d4d\u0d35\u0d3e\u0d32\u0d4d\u200d\u0d2c\u0d3e\u0d30\u0d4d\u200d\u0d21\u0d4d \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d1c\u0d3e\u0d28\u0d4d\u200d \u0d2e\u0d3e\u0d2f\u0d28\u0d4d\u200d',
 u'sk': u'\u0d38\u0d4d\u0d35\u0d4b\u0d35\u0d3e\u0d15\u0d4d\u0d15\u0d3f\u0d2f',
 u'sl': u'\u0d38\u0d3f\u0d2f\u0d3e\u0d31\u0d3e \u0d32\u0d3f\u0d2f\u0d4b\u0d23\u0d4d\u200d',
 u'sm': u'\u0d38\u0d3e\u0d28\u0d4d\u200d \u0d2e\u0d3e\u0d31\u0d3f\u0d28\u0d4b',
 u'sn': u'\u0d38\u0d46\u0d28\u0d46\u0d17\u0d32\u0d4d\u200d',
 u'so': u'\u0d38\u0d4b\u0d2e\u0d3e\u0d32\u0d3f\u0d2f\u0d3e',
 u'sr': u'\u0d38\u0d42\u0d31\u0d3f\u0d28\u0d46\u0d2f\u0d3f\u0d02',
 u'st': u'\u0d38\u0d3e\u0d35\u0d4b \u0d1f\u0d4b\u0d02 \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d2a\u0d4d\u0d30\u0d3f\u0d28\u0d4d\u200d\u0d38\u0d48\u0d2a\u0d4d',
 u'sv': u'\u0d0e\u0d32\u0d4d\u200d \u0d38\u0d3e\u0d32\u0d4d\u200d\u0d35\u0d21\u0d4b\u0d30\u0d4d\u200d',
 u'sy': u'\u0d38\u0d3f\u0d31\u0d3f\u0d2f',
 u'sz': u'\u0d38\u0d4d\u0d35\u0d3e\u0d38\u0d3f\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d',
 u'tc': u'\u0d1f\u0d30\u0d4d\u200d\u0d15\u0d4d\u0d15\u0d4d\u0d38\u0d4d \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d15\u0d2f\u0d3f\u0d15\u0d4d\u0d15\u0d4b\u0d38\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'td': u'\u0d15\u0d4d\u0d2f\u0d3e\u0d21\u0d4d',
 u'tf': u'\u0d2b\u0d4d\u0d30\u0d46\u0d1e\u0d4d\u0d1a\u0d4d \u0d35\u0d1f\u0d15\u0d4d\u0d15\u0d28\u0d4d\u200d \u0d1f\u0d46\u0d31\u0d3f\u0d1f\u0d4d\u0d1f\u0d31\u0d3f\u0d15\u0d33\u0d4d\u200d',
 u'tg': u'\u0d1f\u0d4b\u0d17\u0d4b',
 u'th': u'\u0d24\u0d3e\u0d2f\u0d3f\u0d32\u0d3e\u0d28\u0d4d\u200d\u0d21\u0d4d',
 u'tj': u'\u0d24\u0d1c\u0d3f\u0d15\u0d4d\u0d15\u0d3f\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d4d\u200d',
 u'tk': u'\u0d1f\u0d4b\u0d15\u0d3f\u0d32\u0d3e\u0d35\u0d41',
 u'tl': u'\u0d1f\u0d3f\u0d2e\u0d4b\u0d30\u0d4d\u200d-\u0d32\u0d46\u0d38\u0d4d\u0d24\u0d46',
 u'tm': u'\u0d1f\u0d41\u0d30\u0d4d\u200d\u0d15\u0d4d\u0d15\u0d4d\u0d2e\u0d46\u0d28\u0d3f\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d4d\u200d',
 u'tn': u'\u0d1f\u0d41\u0d23\u0d40\u0d37\u0d4d\u0d2f',
 u'to': u'\u0d1f\u0d4b\u0d19\u0d4d\u0d15\u0d4b',
 u'tr': u'\u0d24\u0d41\u0d30\u0d4d\u200d\u0d15\u0d4d\u0d15\u0d3f',
 u'tt': u'\u0d1f\u0d4d\u0d30\u0d3f\u0d28\u0d3f\u0d21\u0d3e\u0d21\u0d4d\u200c \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d1f\u0d4b\u0d2c\u0d3e\u0d17\u0d4b',
 u'tv': u'\u0d24\u0d41\u0d35\u0d3e\u0d32\u0d41',
 u'tw': u'\u0d24\u0d3e\u0d2f\u0d4d\u200c\u0d35\u0d3e\u0d28\u0d4d\u200d',
 u'tz': u'\u0d1f\u0d3e\u0d28\u0d4d\u200d\u0d38\u0d3e\u0d28\u0d3f\u0d2f\u0d3e',
 u'ua': u'\u0d2f\u0d41\u0d15\u0d4d\u0d30\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u200d',
 u'ug': u'\u0d09\u0d17\u0d3e\u0d23\u0d4d\u0d1f\u0d3e',
 u'um': u'\u0d2f\u0d41\u0d23\u0d48\u0d31\u0d4d\u0d31\u0d21\u0d4d \u0d38\u0d4d\u0d31\u0d4d\u0d31\u0d47\u0d31\u0d4d\u0d31\u0d4d\u0d38\u0d4d \u0d2e\u0d48\u0d28\u0d30\u0d4d\u200d \u0d14\u0d1f\u0d4d\u0d1f\u0d4d\u0d32\u0d2f\u0d3f\u0d19\u0d4d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'us': u'\u0d2f\u0d41\u0d23\u0d48\u0d31\u0d4d\u0d31\u0d21\u0d4d\u200c \u0d38\u0d4d\u0d31\u0d4d\u0d31\u0d47\u0d31\u0d4d\u0d31\u0d4d\u200c\u0d38\u0d4d\u200c',
 u'uy': u'\u0d2f\u0d41\u0d31\u0d41\u0d17\u0d4d\u0d35\u0d47',
 u'uz': u'\u0d09\u0d38\u0d4d\u0d2c\u0d46\u0d15\u0d4d\u0d15\u0d3f\u0d38\u0d4d\u0d25\u0d3e\u0d28\u0d4d\u200d',
 u'va': u'\u0d35\u0d24\u0d4d\u0d24\u0d3f\u0d15\u0d4d\u0d15\u0d3e\u0d28\u0d4d\u200d \u0d38\u0d3f\u0d31\u0d4d\u0d31\u0d3f',
 u'vc': u'\u0d38\u0d46\u0d2f\u0d3f\u0d28\u0d4d\u0d31\u0d4d \u0d35\u0d3f\u0d28\u0d4d\u200d\u0d38\u0d46\u0d28\u0d4d\u0d31\u0d4d \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d17\u0d4d\u0d30\u0d28\u0d46\u0d21\u0d2f\u0d3f\u0d28\u0d4d\u200d\u0d38\u0d4d',
 u've': u'\u0d35\u0d46\u0d28\u0d38\u0d4d\u0d35\u0d47\u0d32',
 u'vg': u'\u0d2c\u0d4d\u0d30\u0d3f\u0d1f\u0d4d\u0d1f\u0d40\u0d37\u0d4d \u0d35\u0d46\u0d30\u0d4d\u200d\u0d1c\u0d3f\u0d28\u0d4d\u200d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'vi': u'\u0d2f\u0d41. \u0d0e\u0d38\u0d4d. \u0d35\u0d3f\u0d30\u0d4d\u200d\u0d1c\u0d3f\u0d28\u0d4d\u200d \u0d26\u0d4d\u0d35\u0d40\u0d2a\u0d41\u0d15\u0d33\u0d4d\u200d',
 u'vn': u'\u0d35\u0d3f\u0d2f\u0d31\u0d4d\u0d31\u0d4d\u0d28\u0d3e\u0d02',
 u'vu': u'\u0d35\u0d28\u0d46\u0d57\u0d1f\u0d41',
 u'wf': u'\u0d35\u0d3e\u0d32\u0d3f\u0d38\u0d4d \u0d06\u0d28\u0d4d\u200d\u0d21\u0d4d \u0d2b\u0d41\u0d1f\u0d41\u0d28\u0d3e',
 u'ws': u'\u0d38\u0d3e\u0d2e\u0d4b\u0d35\u0d3e',
 u'ye': u'\u0d2f\u0d46\u0d2e\u0d28\u0d4d\u200d',
 u'yt': u'\u0d2e\u0d2f\u0d4b\u0d1f\u0d3f',
 u'za': u'\u0d38\u0d4c\u0d24\u0d4d\u0d24\u0d4d\u200c \u0d06\u0d2b\u0d4d\u0d30\u0d3f\u0d15\u0d4d\u0d15',
 u'zm': u'\u0d38\u0d3e\u0d02\u0d2c\u0d3f\u0d2f\u0d3e',
 u'zw': u'\u0d38\u0d3f\u0d02\u0d2c\u0d3e\u0d2c\u0d4d\u200c\u0d35\u0d46'}